@@ -379,11 +379,8 @@ class SQLDiff(object):
             if field_name not in db_fields:
                 field_output = []
 
-                # TODO: Remove 'field.rel' after dropping Django 1.8 support
-                remote_field = field.remote_field if hasattr(field, 'remote_field') else field.rel
-                if remote_field:
-                    remote_field_model = remote_field.model if hasattr(remote_field, 'model') else remote_field.to
-                    field_output.extend([remote_field_model._meta.db_table, remote_field_model._meta.get_field(remote_field.field_name).column])
+                if field.remote_field:
+                    field_output.extend([field.remote_field.model._meta.db_table, field.remote_field.model._meta.get_field(field.remote_field.field_name).column])
                     op = 'fkey-missing-in-db'
                 else:
                     op = 'field-missing-in-db'
@@ -480,7 +477,6 @@ class SQLDiff(object):
                 self.add_difference('table-missing-in-db', table_name)
                 continue
 
-            table_indexes = self.introspection.get_indexes(self.cursor, table_name)
             if hasattr(self.introspection, 'get_constraints'):
                 table_constraints = self.introspection.get_constraints(self.cursor, table_name)
             else:
@@ -499,6 +495,16 @@ class SQLDiff(object):
                 transaction.rollback()  # reset transaction
                 continue
 
+            # map table_contraints into table_indexes
+            table_indexes = {}
+            for _, dct in table_constraints.items():
+                columns = dct['columns']
+                if len(columns) == 1:
+                    table_indexes[columns[0]] = {
+                        'primary_key': dct['primary_key'],
+                        'unique': dct['unique'],
+                    }
+
             # Fields which are defined in database but not in model
             # 1) find: 'unique-missing-in-model'
             self.find_unique_missing_in_model(meta, table_indexes, table_constraints, table_name)
