@@ -8,6 +8,8 @@ Based on:
   Adapted to be used with django-extensions
 """
 
+# from __future__ import unicode_literals
+
 import datetime
 import os
 import re
@@ -19,7 +21,7 @@ from django.db.models.fields.related import (
 )
 from django.contrib.contenttypes.fields import GenericRelation
 from django.template import Context, Template, loader
-from django.utils.encoding import force_bytes, force_str
+from django.utils.encoding import force_text
 from django.utils.safestring import mark_safe
 from django.utils.translation import activate as activate_language
 
@@ -41,6 +43,7 @@ __contributors__ = [
     "Adam Dobrawy <naczelnik@jawnosc.tk>",
     "Mikkel Munch Mortensen <https://www.detfalskested.dk/>",
     "Andrzej Bistram <andrzej.bistram@gmail.com>",
+    "Daniel Lipsitt <danlipsitt@gmail.com>",
 ]
 
 
@@ -114,7 +117,7 @@ class ModelGraph(object):
 
     def add_attributes(self, field, abstract_fields):
         if self.verbose_names and field.verbose_name:
-            label = force_bytes(field.verbose_name)
+            label = force_text(field.verbose_name)
             if label.islower():
                 label = label.capitalize()
         else:
@@ -122,8 +125,7 @@ class ModelGraph(object):
 
         t = type(field).__name__
         if isinstance(field, (OneToOneField, ForeignKey)):
-            remote_field = field.remote_field if hasattr(field, 'remote_field') else field.rel  # Remove me after Django 1.8 is unsupported
-            t += " ({0})".format(remote_field.field_name)
+            t += " ({0})".format(field.remote_field.field_name)
         # TODO: ManyToManyField, GenericRelation
 
         return {
@@ -138,7 +140,7 @@ class ModelGraph(object):
 
     def add_relation(self, field, model, extras=""):
         if self.verbose_names and field.verbose_name:
-            label = force_bytes(field.verbose_name)
+            label = force_text(field.verbose_name)
             if label.islower():
                 label = label.capitalize()
         else:
@@ -149,23 +151,21 @@ class ModelGraph(object):
             related_query_name = field.related_query_name()
             if self.verbose_names and related_query_name.islower():
                 related_query_name = related_query_name.replace('_', ' ').capitalize()
-            label = '{} ({})'.format(label, force_str(related_query_name))
+            label = '{} ({})'.format(label, force_text(related_query_name))
 
         # handle self-relationships and lazy-relationships
-        remote_field = field.remote_field if hasattr(field, 'remote_field') else field.rel  # Remove me after Django 1.8 is unsupported
-        remote_field_model = remote_field.model if hasattr(remote_field, 'model') else remote_field.to  # Remove me after Django 1.8 is unsupported
-        if isinstance(remote_field_model, six.string_types):
-            if remote_field_model == 'self':
+        if isinstance(field.remote_field.model, six.string_types):
+            if field.remote_field.model == 'self':
                 target_model = field.model
             else:
-                if '.' in remote_field_model:
-                    app_label, model_name = remote_field_model.split('.', 1)
+                if '.' in field.remote_field.model:
+                    app_label, model_name = field.remote_field.model.split('.', 1)
                 else:
                     app_label = field.model._meta.app_label
-                    model_name = remote_field_model
+                    model_name = field.remote_field.model
                 target_model = apps.get_model(app_label, model_name)
         else:
-            target_model = remote_field_model
+            target_model = field.remote_field.model
 
         _rel = self.get_relation_context(target_model, field, label, extras)
 
@@ -215,7 +215,7 @@ class ModelGraph(object):
         }
 
         if self.verbose_names and appmodel._meta.verbose_name:
-            context['label'] = force_bytes(appmodel._meta.verbose_name)
+            context['label'] = force_text(appmodel._meta.verbose_name)
         else:
             context['label'] = context['name']
 
@@ -329,8 +329,7 @@ class ModelGraph(object):
         if self.skip_field(field):
             return newmodel
         if isinstance(field, ManyToManyField):
-            remote_field = field.remote_field if hasattr(field, 'remote_field') else field.rel  # Remove me after Django 1.8 is unsupported
-            if hasattr(remote_field.through, '_meta') and remote_field.through._meta.auto_created:
+            if hasattr(field.remote_field.through, '_meta') and field.remote_field.through._meta.auto_created:
                 newmodel['relations'].append(self.add_relation(field, newmodel, '[arrowhead=dot arrowtail=dot, dir=both]'))
         elif isinstance(field, GenericRelation):
             newmodel['relations'].append(self.add_relation(field, newmodel, mark_safe('[style="dotted", arrowhead=normal, arrowtail=normal, dir=both]')))
